<?php

namespace Teknisa\MAN\Controllers;
use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Utilities;
use Teknisa\MAN\Services\ManutencaoBeneficioService;

class ManutencaoBeneficioDisponivel extends CrudWithParameterBag {

    protected $dataSourceName = 'manutencaoBeneficioDisponivel';
    protected $parameterBagColumns = array('NRORG', 'CDCLIENTE', 'CDCONSUMIDOR', 'NRSEQPRODCAMP', 'CDCAMPANHA');
    protected $manutencaoBeneficioService;
    
    public function __construct (ManutencaoBeneficioService $manutencaoBeneficioService, Manager $dataSourceManager, ParameterBag $parameterBag, Utilities\Util $utilService, $connection) {
        $this->ManutencaoBeneficioService = $manutencaoBeneficioService;
        $this->utilService = $utilService;
        parent::__construct($dataSourceManager, $parameterBag);
        $this->connection = $connection;
        
    }
    
	public function deleteWithoutNotification ($request, $response) {
		try {
            $data = $request->getDataSet()->getRows()[0];
            $CDCAMPANHA        = ($data['CDCAMPANHA']      ? $data['CDCAMPANHA']         : NULL);
            $CDCLIENTE         = ($data['CDCLIENTE']       ? $data['CDCLIENTE']          : NULL);
            $CDCONSUMIDOR      = ($data['CDCONSUMIDOR']    ? $data['CDCONSUMIDOR']       : NULL);
            $NRSEQBENEFICIO    = ($data['NRSEQBENEFICIO']  ? $data['NRSEQBENEFICIO']     : NULL);
            $NRSEQPRODCAMP     = ($data['NRSEQPRODCAMP']   ? $data['NRSEQPRODCAMP']      : NULL);
            $NRORG             = ($data['NRORG']           ? $data['NRORG']              : NULL);
            
            $this->ManutencaoBeneficioService->deleteBeneficios($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQPRODCAMP, $NRSEQBENEFICIO, $NRORG);
            
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
	}
    
    
    public function save(DTO\Request\DataSet $request, DTO\Response $response) {
        $data = $request->getDataSet()->getRows()[0];
        $CDCAMPANHA        = ($data['CDCAMPANHA']      ? $data['CDCAMPANHA']         : NULL);
        $CDCLIENTE         = ($data['CDCLIENTE']       ? $data['CDCLIENTE']          : NULL);
        $CDCONSUMIDOR      = ($data['CDCONSUMIDOR']    ? $data['CDCONSUMIDOR']       : NULL);
        $IDTPBENEFICIO     = ($data['IDTPBENEFICIO']   ? $data['IDTPBENEFICIO']      : NULL);
        $NRSEQBENEFICIO    = ($data['NRSEQBENEFICIO']  ? $data['NRSEQBENEFICIO']     : NULL);
        $NRSEQPRODCAMP     = ($data['NRSEQPRODCAMP']   ? $data['NRSEQPRODCAMP']      : NULL);
        $QTDEBENEFICIO     = ($data['QTDEBENEFICIO']   ? $data['QTDEBENEFICIO']      : NULL);
        $VRBENEFICIO       = ($data['VRBENEFICIO']     ? $data['VRBENEFICIO']        : NULL);
        $NRORG             = ($data['NRORG']           ? $data['NRORG']              : NULL);
        $NRORGINCLUSAO     = ($data['NRORGINCLUSAO']   ? $data['NRORGINCLUSAO']      : NULL);
        $CDOPERINCLUSAO    = ($data['CDOPERINCLUSAO']  ? $data['CDOPERINCLUSAO']     : NULL);
        $DTINIVALBENECONS  = ($data['DTINIVALBENECONS']? $data['DTINIVALBENECONS']   : NULL);
        $DTFIMVALBENECONS  = ($data['DTFIMVALBENECONS']? $data['DTFIMVALBENECONS']   : NULL);
        $NRORGULTATU    = '';
        $CDOPERULTATU   = '';
        if($DTINIVALBENECONS && $DTFIMVALBENECONS){
            if($data['__is_new']){
                $retorno = $this->ManutencaoBeneficioService->insereManutencaoBeneficio($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $DTINIVALBENECONS, $DTFIMVALBENECONS, $IDTPBENEFICIO, $NRSEQBENEFICIO, $QTDEBENEFICIO, $VRBENEFICIO, $NRORG, $NRORGINCLUSAO, $CDOPERINCLUSAO, $NRORG, $CDOPERINCLUSAO, $NRSEQPRODCAMP);
            }else{
                $retorno = $this->ManutencaoBeneficioService->updateManutencaoBeneficio($QTDEBENEFICIO, $NRORGULTATU, $CDOPERULTATU, $CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR, $NRSEQPRODCAMP, $NRSEQBENEFICIO);
            }
        
            $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('ManutencaoBeneficio', array($retorno)));
        }else{
               $this->ManutencaoBeneficioService->updateBenefitExpiration($CDCLIENTE, $CDCONSUMIDOR, $CDCAMPANHA, $NRSEQBENEFICIO, $DTINIVALBENECONS, $DTFIMVALBENECONS,  $QTDEBENEFICIO);
                
                $availableBenefits = $this->ManutencaoBeneficioService->buscaBeneficiosDisponiveis($CDCAMPANHA, $CDCLIENTE, $CDCONSUMIDOR);
                
                for($i = 0; $i < count($availableBenefits); ++$i){
                    if ($availableBenefits[$i]['IDTPBENEFICIO'] == 'P')
                        $availableBenefits[$i]['LABEL'] = $availableBenefits[$i]['NRSEQBENEFICIO'] .' DESCONTO PERCENTUAL '. $availableBenefits[$i]['VRBENEFICIO'].'%' ;
                    else
                        $availableBenefits[$i]['LABEL'] = $availableBenefits[$i]['NRSEQBENEFICIO'] .' DESCONTO VALOR '. $this->util->formataDinheiro($availableBenefits[$i]['VRBENEFICIO']);
                }
                $response->addDataSet(new \Zeedhi\Framework\DataSource\DataSet('BenDisponiveisRepo', $availableBenefits));
            
        }
    }

}
